
RELEASE_VERSION='0.0.431976398'
BUILD_DATE='Fri Dec 17 14:37:16 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-07fvsc 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1897299762'
GIT_COMMIT_SHA='fe86f0892d09ec9a3d71411e82e290c7154ea542'
GIT_BRANCH='main'
